<!-- Thank you for your contribution! -->

## Change Summary

<!-- Please give a short summary of the changes. -->

## Related issue number

<!-- Are there any issues opened that will be resolved by merging this change? -->
<!-- WARNING: please use "fix #123" style references so the issue is closed when this PR is merged. -->

## Checklist

- [ ] Unit tests for the changes exist
- [ ] Documentation reflects the changes where applicable
- [ ] Ping-rs tests pass with this `ping-rs` (except for expected changes)
- [ ] My PR is ready to review, **please add a comment including the phrase "please review" to assign reviewers**
